﻿using CoreFoundation;
using Syncfusion.SfDataGrid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UIKit;

namespace GroupDemo
{
    public class IncrementalLoadingViewModel : INotifyPropertyChanged
    {
        #region Field

        internal OrderInfoRepository orderInfoReporsitory;

        #endregion

        #region Ctor

        public UIActivityIndicatorView LoaderIndicator;
        public UILabel LoaderLable;
        public UIView LoaderBorder;

        public IncrementalLoadingViewModel()
        {
            orderInfoReporsitory = new OrderInfoRepository();
            LoaderBorder = new UIView();
            this.LoaderLable = new UILabel();
            this.LoaderIndicator = new UIActivityIndicatorView();
            this.LoaderIndicator.Color = UIColor.FromRGB(255, 255, 255);
			LoaderBorder.BackgroundColor = UIColor.FromRGB(70, 183, 118).ColorWithAlpha(.6f);
            LoaderBorder.Add(LoaderLable);
            LoaderBorder.Add(LoaderIndicator);
            gridSource = new IncrementalList<OrderInfo>(LoadMoreItems) { MaxItemCount = 1000 };
        }

        #endregion

        #region Properties

        private IncrementalList<OrderInfo> gridSource;

        public IncrementalList<OrderInfo> GridSource
        {
            get { return gridSource; }
            set
            {
                gridSource = value;
                RaisePropertyChanged("GridSource");
            }
        }

        private bool isBusy;

        public bool IsBusy
        {
            get { return isBusy; }
            set
            {
                isBusy = value;
                if (isBusy)
                {
                    this.LoaderLable.Text = "Fetching Data... ";
                }
                else
                {
                    if (noNetwork)
                    {
                        LoaderLable.LineBreakMode = UILineBreakMode.WordWrap;
                        LoaderLable.Lines = 0;
                        this.LoaderLable.Text = "No Network Found..! \nSearching for a network...";
                    }
                }
                RaisePropertyChanged("IsBusy");
            }
        }

        private bool noNetwork;

        public bool NoNetwork
        {
            get { return noNetwork; }
            set
            {
                noNetwork = value;
                RaisePropertyChanged("NoNetwork");
            }
        }


        #endregion

        #region INotifyPropertyChanged Member

        public event PropertyChangedEventHandler PropertyChanged;

        void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region Methods

        async void LoadMoreItems(uint count, int baseIndex)
        {
            IsBusy = true;
            this.LoaderLable.Hidden = false;
            LoaderBorder.Hidden = false;
            UIView.Animate(2, () =>
            {

                this.LoaderIndicator.StartAnimating();
            });
            await Task.Delay(2000);
            GridSource.LoadItems(orderInfoReporsitory.GetOrderDetails((int)count));

            IsBusy = false;
            UIView.Animate(2, () =>
            {
                for (int i = 5; i < 0; i--)
                {
                    LoaderBorder.Alpha = i - 0.1f;
                }

                LoaderBorder.Hidden = true;
            });
            this.LoaderIndicator.StopAnimating();
            this.LoaderIndicator.HidesWhenStopped = true;
            this.LoaderLable.Hidden = true;
        }

        #endregion
    }
}
